@@ -10,7 +10,7 @@ gi.require_version("PackageKitGlib", "1.0")
 from gi.repository import Gtk, GLib
 from gi.repository import PackageKitGlib as packagekit
 
-from aptdaemon.gtk3widgets import AptProgressDialog
+from aptkit.gtk3widgets import AptProgressDialog
 
 from .pkgInfo import AptPkgInfo
 from .dialogs import ChangesConfirmDialog
@@ -68,7 +68,7 @@ def process_full_apt_cache(cache):
         name = apt_cache[key].name
         pkg = apt_cache[key]
 
-        if name.startswith("lib") and not name.startswith(("libreoffice", "librecad", "libk3b7", "libimage-exiftool-perl")):
+        if name.startswith("lib") and not name.startswith(("libreoffice", "librecad", "librewolf", "libk3b7", "libimage-exiftool-perl")):
             continue
         if name.endswith(":i386") and name != "steam:i386":
             continue
